@@ -1,5 +1,6 @@
 import os
 import sys
+import logging
 from subprocess import Popen, PIPE
 
 from sbdk.auth import login
@@ -21,6 +22,7 @@ def upload(project, file):
     usr, sid = login(project)
     user_home = '/home/%s' % usr
     dest = os.path.join(user_home, os.path.basename(file))
-    args = [executable, '-o', 'u', '-session-id', '-s', server, '-ssl', '-lf', file, '-rf', dest]
-    p = Popen(args, stdin=PIPE, stdout=PIPE, stderr=PIPE)
+    args = [executable, '-o', 'u', '-sessionId', '-s', server, '-ssl', '-lf', file, '-rf', dest]
+    logging.debug('Running cmd: %s', args)
+    p = Popen(args, stdin=PIPE)
     p.communicate('%s\n' % sid)
\ No newline at end of file
