@@ -20,7 +20,7 @@ DEFAULT_CONFIG = {
     'pip_options': '-q --download-cache /sb/pip_cache',
     'sdk_runner_command': ['/usr/bin/python', '-m', 'sbgsdk.cli'],
     'schema_server_url': 'https://lair.sbgenv.com:1180',
-    'file_server_url': 'https://lair.sbgenv.com:22443',
+    'file_server_url': 'lair.sbgenv.com',
     'vs_client_path': '/opt/vsclient/bin/vsclient.sh',
 
     'docker_registry_name': 'docker.sbgenomics.com:8888',
